==> okteta-0.25.0.tar.xz: okteta-0.25.0/kasten/gui/io/generator/pattern/bytearraypatterngeneratorconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYPATTERNGENERATORCONFIGEDITORFACTORY_H
#define BYTEARRAYPATTERNGENERATORCONFIGEDITORFACTORY_H

// lib
#include <kasten/okteta/oktetakastengui_export.h>
// Kasten gui
#include <kasten/abstractmodeldatageneratorconfigeditorfactory.h>

namespace Kasten {

class ByteArrayPatternGeneratorConfigEditorFactory : public AbstractModelDataGeneratorConfigEditorFactory
{
public:
    ByteArrayPatternGeneratorConfigEditorFactory();

    ~ByteArrayPatternGeneratorConfigEditorFactory() override;

public:
    AbstractModelDataGeneratorConfigEditor* tryCreateConfigEditor(AbstractModelDataGenerator* generator) const override;
};

}

#endif

==> okteta_16.04.3.orig.tar.xz: okteta-16.04.3/kasten/gui/io/generator/pattern/bytearraypatterngeneratorconfigeditorfactory.h <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef BYTEARRAYPATTERNGENERATORCONFIGEDITORFACTORY_H
#define BYTEARRAYPATTERNGENERATORCONFIGEDITORFACTORY_H

// lib
#include <kasten/okteta/oktetakastengui_export.h>
// Kasten gui
#include <kasten/abstractmodeldatageneratorconfigeditorfactory.h>


namespace Kasten
{

class ByteArrayPatternGeneratorConfigEditorFactory : public AbstractModelDataGeneratorConfigEditorFactory
{
  public:
    ByteArrayPatternGeneratorConfigEditorFactory();

    virtual ~ByteArrayPatternGeneratorConfigEditorFactory();

  public:
    virtual AbstractModelDataGeneratorConfigEditor* tryCreateConfigEditor( AbstractModelDataGenerator* generator ) const;
};

}

#endif
